pub enum FileType {
File,
Dir,
Symlink,
}Expand description
Type of a file on disk
There are currently there forms of files supported by this
library: File, Dir and
Symlink (please notice that
VirtualDiskit does not support
symlinks).
Variants
Implementations
Sourceimpl FileType
impl FileType
Sourcepub fn is_dir(&self) -> bool
pub fn is_dir(&self) -> bool
Returns whether the file is a directory
This function returns whether the file is a directory.
Sourcepub fn is_file(&self) -> bool
pub fn is_file(&self) -> bool
Returns whether the file is a normal file
This function returns whether the file is a normal file.
Sourcepub fn is_symlink(&self) -> bool
pub fn is_symlink(&self) -> bool
Returns whether the file is a symlink
This function returns whether the file is a symlink.